@@ -1,14 +1,15 @@
 package Cassandra::Client::Connection;
 our $AUTHORITY = 'cpan:TVDW';
-$Cassandra::Client::Connection::VERSION = '0.13_003'; # TRIAL
+$Cassandra::Client::Connection::VERSION = '0.13_004'; # TRIAL
 
-$Cassandra::Client::Connection::VERSION = '0.13003';use 5.010;
+$Cassandra::Client::Connection::VERSION = '0.13004';use 5.010;
 use strict;
 use warnings;
 use vars qw/$BUFFER/;
 
 use Ref::Util qw/is_blessed_ref is_plain_arrayref/;
 use IO::Socket::INET;
+use IO::Socket::INET6;
 use Errno qw/EAGAIN/;
 use Socket qw/SOL_SOCKET IPPROTO_TCP SO_KEEPALIVE TCP_NODELAY/;
 use Scalar::Util qw/weaken/;
@@ -666,12 +667,23 @@ sub connect {
     my $socket; {
         local $@;
 
-        $socket= IO::Socket::INET->new(
-            PeerAddr => $self->{host},
-            PeerPort => $self->{options}{port},
-            Proto    => 'tcp',
-            Blocking => 0,
-        );
+        if ($self->{host} =~ /:/) {
+            # IPv6
+            $socket= IO::Socket::INET6->new(
+                PeerAddr => $self->{host},
+                PeerPort => $self->{options}{port},
+                Proto    => 'tcp',
+                Blocking => 0,
+            );
+        } else {
+            # IPv6
+            $socket= IO::Socket::INET->new(
+                PeerAddr => $self->{host},
+                PeerPort => $self->{options}{port},
+                Proto    => 'tcp',
+                Blocking => 0,
+            );
+        }
 
         unless ($socket) {
             my $error= "Could not connect: $@";
@@ -1091,7 +1103,7 @@ Cassandra::Client::Connection
 
 =head1 VERSION
 
-version 0.13_003
+version 0.13_004
 
 =head1 AUTHOR
 
