@@ -1,8 +1,8 @@
 package Cassandra::Client::NetworkStatus;
 our $AUTHORITY = 'cpan:TVDW';
-$Cassandra::Client::NetworkStatus::VERSION = '0.13_003'; # TRIAL
+$Cassandra::Client::NetworkStatus::VERSION = '0.13_004'; # TRIAL
 
-$Cassandra::Client::NetworkStatus::VERSION = '0.13003';use 5.010;
+$Cassandra::Client::NetworkStatus::VERSION = '0.13004';use 5.010;
 use strict;
 use warnings;
 
@@ -40,6 +40,8 @@ sub select_master {
     }
     push @{$self->{waiting_for_cb}}, $callback;
 
+    my $pool= $self->{pool}; # non-weak
+
     my $attempts= 0;
     whilst(
         sub { # condition
@@ -59,7 +61,7 @@ sub select_master {
                 },
                 sub {
                     my ($next)= @_;
-                    $self->{pool}->get_one_cb($next);
+                    $pool->get_one_cb($next);
                 },
                 sub {
                     my ($next, $connection)= @_;
@@ -167,7 +169,7 @@ Cassandra::Client::NetworkStatus
 
 =head1 VERSION
 
-version 0.13_003
+version 0.13_004
 
 =head1 AUTHOR
 
